RpcMode

Enum RpcMode 

pub enum RpcMode {
    Sequencer {
        block_producer: Box<BlockProducerApi>,
        validator: Box<ValidatorClient>,
    },
    FullNode {
        source_rpc: Box<RpcClient>,
        readiness_threshold: u32,
        validator: Option<Box<ValidatorClient>>,
        sequencer: Option<Box<SequencerClient>>,
    },
}

Variants



Sequencer

Sequencer RPC validates submissions locally, re-executes them through the validator, then forwards them to the block producer.

Fields

block_producer: Box<BlockProducerApi>


FullNode

Full-node RPC.

By default it forwards submissions verbatim to the source RPC (the caller is responsible for configuring this client with any request metadata the source RPC requires).

When the validator and sequencer clients are set, the full-node will, instead of forwarding, re-execute submissions through the validator and authenticate them against its store, then submit the authenticated result directly to the sequencer’s internal API.

Fields

source_rpc: Box<RpcClient>
readiness_threshold: u32

Implementations

Source

impl RpcMode

pub fn sequencer( block_producer: BlockProducerApi, validator: ValidatorClient, ) -> Self

pub fn full_node( source_rpc: SourceRpcClient, readiness_threshold: u32, validator: Option<ValidatorClient>, sequencer: Option<SequencerClient>, ) -> Self